==> ircii-2.8.36-pana.tar.gz: ircii-2.8/source/notice.c <==
/*
 * notice.c: special stuff for parsing NOTICEs
 *
 * Written By Michael Sandrof
 *
 * Copyright(c) 1991
 *
 * See the COPYRIGHT file, or do a HELP IRCII COPYRIGHT 
 */
#define COMPAT_27

#include "irc.h"

#include "whois.h"
#include "ctcp.h"
#include "window.h"
#include "lastlog.h"
#include "flood.h"
#include "vars.h"
#include "ircaux.h"
#include "hook.h"
#include "ignore.h"
#include "server.h"
#include "funny.h"
#include "output.h"
#include "names.h"
#include "parse.h"
#include "notify.h"
#include "pluto.h"

extern	char	*FromUserHost;
static	void	parse_server_notice _((char *, char *));
extern char *last_notice;
extern void reload_save _((char *, char *, char *));

static	void
parse_server_notice(from, line)
	char	*from,
		*line;
{
	int	lastlog_level;
	int	flag;
	
	char *fr, *for_, *temp, *temp2, *server, *server2;

	if (!from || !*from)
		from = server_list[from_server].itsname ?
			server_list[from_server].itsname :
			server_list[from_server].name;
#ifdef COMPAT_27
	if (get_int_var(SUPPRESS_SERVER_MOTD_VAR) &&
		get_server_motd(from_server))
	{
		if (strncmp("*** Message-of-today", line, 20) == 0)
		{
			set_server_motd(from_server, 0);
			return;
		}
		if (strncmp("MOTD ", line, 5) == 0)
		{
			set_server_motd(from_server, 1);
			return;
		}
		if (strcmp("* End of /MOTD command.", line) == 0)
		{
			set_server_motd(from_server, 0);
			return;
		}
	}
        else if (!get_server2_8(from_server) && (!strncmp(line, "*** Your host is ", 17)))
                got_initial_version(line);
	else
#endif	
	if (!strncmp(line, "*** Notice --", 13))
	{
		message_from(NULL, LOG_OPNOTE);
		lastlog_level = set_lastlog_msg_level(LOG_OPNOTE);
	}

	message_from(NULL, LOG_SNOTE);
	lastlog_level = set_lastlog_msg_level(LOG_SNOTE);
	
	if (*line != '*'  && *line != '#' && strncmp(line, "MOTD ", 4))
		flag = 1;
	else
		flag = 0;

  
	split_kill(line, &fr, &temp2,
			&server, &server2, &for_, &temp); 
	if (!fr || !for_)
		return;
	if (!server)
		server = "Local";
	if (!server2)
		server2 = "Local";
	if (!temp2)
		temp2 = "UNKNOWN";
	if (!temp)
		temp = "()";	

	if (strstr(line, "Notice -- Received KILL message for"))
	{
		if ((strcmp(server, "Local") == 0))
		{
			if (do_hook(SERVER_NOTICE_LOCAL_KILL_LIST, "%s %s %s %s", for_, server, fr, temp2, temp))
				say("Local Ircop Kill for %s by %s %s (%s %s)", for_, fr, temp2, server, temp);
		} else {
			if (do_hook(SERVER_NOTICE_FOREIGN_KILL_LIST, "%s %s %s %s", for_, server, fr, temp2, temp))
				say("Foreign Ircop Kill for %s by %s %s (%s %s)", for_, fr, temp2, server, temp);
		}
 	} 
 	else if (strstr(line, "Notice -- Nick change collision"))
	{
		if (do_hook(SERVER_NOTICE_SERVER_KILL_LIST,"%s %s %s %s", for_, fr, temp2, server, temp))
			put_it(flag ? "*** %s" : "%s", line);
	}
	else if (strstr(line, "Notice -- Nickname collision"))
	{
		if (do_hook(SERVER_NOTICE_SERVER_KILL_LIST, "%s %s %s %s", for_, fr, temp2, server, temp))
			put_it(flag ? "*** %s" : "%s", line);
	}
  	else if (strstr(line, "Notice -- Fake"))
  	{
		/* SERVER_NOTICE_FAKES_MYCHANNEL_LIST */
		if (lookup_channel(fr, from_server, CHAN_NOUNLINK))
		{
			if (do_hook(SERVER_NOTICE_FAKES_MYCHANNEL_LIST, "%s %s %s %s", for_, fr, temp2, server, temp))
  				put_it(flag ? "*** %s" : "%s", line);
		}
		else 
		{
			if (do_hook(SERVER_NOTICE_FAKES_LIST, "%s %s %s %s", for_, fr, temp2, server, temp))
  				put_it(flag ? "*** %s" : "%s", line);
		}
  	}
	else
	{
		if (do_hook(SERVER_NOTICE_LIST, flag ? "%s *** %s" : "%s %s", from, line))
	               	put_it(flag ? "*** %s" : "%s", line);
	}
	if (lastlog_level)
	{
		set_lastlog_msg_level(lastlog_level);
		message_from(NULL, lastlog_level);
	}
}

void 
parse_notice(from, Args)
	char 	*from;
	char 	**Args;
{
	int	level,
		type;
	char	*to;
	int	no_flooding;
	int	flag;
	char	*high,
		not_from_server = 1;
	char	*line;
	char    msg[BIG_BUFFER_SIZE +1];
	
	PasteArgs(Args, 1);
	to = Args[0];
	line = Args[1];
	if (!to || !line)
		return;
	if (*to)
	{
		if (is_channel(to))
		{
			message_from(to, LOG_NOTICE);
			type = PUBLIC_NOTICE_LIST;
		}
		else
		{
			message_from(from, LOG_NOTICE);
			type = NOTICE_LIST;
		}
		update_stats(type, to, from);		
		if (from && *from && strcmp(get_server_itsname(from_server), from))
		{
			switch ((flag = check_ignore(from, FromUserHost, IGNORE_NOTICES)))
			{
				case IGNORED:
					return;
				case HIGHLIGHTED:
					high = highlight_char;
					break;
				default:
					high = empty_string;
			}
		/*
		 * only dots in servernames, right ?
		 *
		 * But a server name doesn't nessicarily have to have
		 * a 'dot' in it..  - phone, jan 1993.
		 */
			if (index(from, '.'))
				not_from_server = 0;
			
			line = do_notice_ctcp(from, to, line);
			if (*line == (char) 0)
				return;
			level = set_lastlog_msg_level(LOG_NOTICE);
			no_flooding = check_flooding(from, NOTICE_FLOOD, line);
			
			if (sed == 1 && !do_hook(ENCRYPTED_NOTICE_LIST, "%s %s %s", from, to, line))
				sed = 0;
			else
			{
				if (type == NOTICE_LIST && no_flooding)
				{
					logmsg(0, "-", from, line, FromUserHost, 0);
					if (do_hook(type, "%s %s", from, line))
						put_it("%s-%s-%s %s", high, from, high, line);
				}
				else
				{
					new_free(&last_notice);
					last_notice = m_sprintf("%s-%s:%s-%s %s", high, from, high, to, line);
					if (do_hook(type, "%s %s %s", from, to, line))
						put_it("%s-%s:%s-%s %s", high, from, to, high, line);
                		        if (get_int_var(ANNOY_KICK_VAR))
						annoy_kicks(type, to, from, line);
					if (beep_on_level & LOG_NOTICE)
						beep_em(1);
				}
				new_free(&last_notice);
				sprintf(msg, "\002-%s:%s-\002 %s", from, to, line);
				malloc_strcpy(&last_notice, msg);
				set_lastlog_msg_level(level);
				if (not_from_server)
					notify_mark(from, 1, 0);
			}
		}
		else 
			parse_server_notice(from, line);
	}
	else
		put_it("%s", line + 1);
}

#ifdef COMPAT_27
/* got_initial_version: this is called when ircii get the NOTICE in
 * all version of ircd before 2.8, or the 002 numeric for 2.8 and
 * beyond.  I guess its handled rather badly at the moment....
 * added by phone, late 1992.
 */
void
got_initial_version(line)
	char	*line;
{
	char	server[81],
		sversion[21];
	char	*c;
	
	if ((sscanf(line, "*** Your host is %80s running version %20s",
			server, sversion)) != 2)
		return;
			
	server[strlen(server) - 1] = '\0';
	attempting_to_connect--;
	set_server_motd(from_server, 1);
	server_is_connected(from_server, 1);
	if ((c = (char *) index(server, '[')) != NULL)
		*c = '\0';	/*
				 * Handles the case where the server name is
				 * different to the host name.
				 */
	set_server_version(from_server, Server2_7);

	malloc_strcpy(&server_list[from_server].version_string, sversion);
	set_server_itsname(from_server, server);
	reconnect_all_channels(from_server);
	reinstate_user_modes(); 
	if (never_connected)
	{
		never_connected = 0;
		loading_global = 1;
		load("LOAD", "global", empty_string);
		loading_global = 0;
		/* read the .ircrc file */
		if (access(ircrc_file, R_OK) == 0 && !quick_startup)
			load(empty_string, ircrc_file, empty_string);

		else if (get_int_var(NOVICE_VAR))
			say("If you have not already done so, please read the new user information with /HELP NEWUSER");
		/* read the .irclistrc file */
		if (!quick_startup)
			reload_save(NULL, NULL, NULL);
	}
	else if (server_list[from_server].away)
		send_to_server("AWAY :%s",
			server_list[from_server].away);
	update_all_status();
	do_hook(CONNECT_LIST, "%s %d", get_server_name(from_server),
		get_server_port(from_server));
}
#endif

/*
 * got_initial_version_28: this is called when ircii gets the serial
 * number 004 reply.  We do this becuase the 004 numeric gives us the
 * server name and version in a very easy to use fashion, and doesnt
 * rely on the syntax or construction of the 002 numeric.
 *
 * Hacked as neccesary by jfn, May 1995
 */
#ifdef __STDC__
extern void got_initial_version_28 (char **ArgList)
#else
extern void	got_initial_version_28(ArgList)
char	**ArgList;
#endif
{
	char *server, *sversion;

	server = ArgList[0];
	sversion = ArgList[1];
	
	attempting_to_connect--;
	set_server_motd(from_server, 1);
	server_is_connected(from_server, 1);
/*
	add_userhost_to_whois(get_server_nickname(from_server), got_my_userhost);
*/

	if (!strncmp(version, "2.8", 3))
	{
		if (strstr(version, "mu") || strstr(version, "me"))
			set_server_version(from_server, Server_u2_8);
		else
			set_server_version(from_server, Server2_8);
	}
	else if (!strncmp(version, "u2.9", 4))
		set_server_version(from_server, Server_u2_9);
	else if (!strncmp(version, "u2.10", 4))
		set_server_version(from_server, Server_u2_10);
	else if (!strncmp(version, "u3.0", 4))
		set_server_version(from_server, Server_u3_0);
	else
		set_server_version(from_server, Server2_8);

	malloc_strcpy(&server_list[from_server].version_string, sversion);
	set_server_itsname(from_server, server);
	reconnect_all_channels(from_server);
	reinstate_user_modes();
	if (never_connected)
	{
		char buffer[BIG_BUFFER_SIZE+1];
		strcpy(buffer, "global");

		never_connected = 0;

		loading_global = 1;
		load("LOAD", buffer, empty_string);
		loading_global = 0;

		/* read the .ircrc file */
		if (access(ircrc_file, R_OK) == 0 && !quick_startup)
			load("LOAD", ircrc_file, empty_string);
		if (!quick_startup)
			reload_save(NULL, NULL, NULL);

		else if (get_int_var(NOVICE_VAR))
			say("If you have not already done so, please read the new user information with /HELP NEWUSER");
	}
	else if (server_list[from_server].away)
		send_to_server("AWAY :%s", server_list[from_server].away);

	update_all_status();
	do_hook(CONNECT_LIST, "%s %d", get_server_name(from_server),
		get_server_port(from_server));
}

==> ircii-2.8.43-pana.tar.gz: ircii-2.8/source/notice.c <==
/*
 * notice.c: special stuff for parsing NOTICEs
 *
 * Written By Michael Sandrof
 *
 * Copyright(c) 1991
 *
 * See the COPYRIGHT file, or do a HELP IRCII COPYRIGHT 
 */
#define COMPAT_27

#include "irc.h"

#include "whois.h"
#include "ctcp.h"
#include "window.h"
#include "lastlog.h"
#include "flood.h"
#include "vars.h"
#include "ircaux.h"
#include "hook.h"
#include "ignore.h"
#include "server.h"
#include "funny.h"
#include "output.h"
#include "names.h"
#include "parse.h"
#include "notify.h"
#include "pluto.h"

extern	char	*FromUserHost;
static	void	parse_server_notice _((char *, char *));
extern char *last_notice;
extern void reload_save _((char *, char *, char *));

static	void
parse_server_notice(from, line)
	char	*from,
		*line;
{
	int	lastlog_level;
	int	flag;
	
	char *fr, *for_, *temp, *temp2, *server, *server2;

	if (!from || !*from)
		from = server_list[from_server].itsname ?
			server_list[from_server].itsname :
			server_list[from_server].name;
#ifdef COMPAT_27
	if (get_int_var(SUPPRESS_SERVER_MOTD_VAR) &&
		get_server_motd(from_server))
	{
		if (strncmp("*** Message-of-today", line, 20) == 0)
		{
			set_server_motd(from_server, 0);
			return;
		}
		if (strncmp("MOTD ", line, 5) == 0)
		{
			set_server_motd(from_server, 1);
			return;
		}
		if (strcmp("* End of /MOTD command.", line) == 0)
		{
			set_server_motd(from_server, 0);
			return;
		}
	}
        else if (!get_server2_8(from_server) && (!strncmp(line, "*** Your host is ", 17)))
                got_initial_version(line);
	else
#endif	
	if (!strncmp(line, "*** Notice --", 13))
	{
		message_from(NULL, LOG_OPNOTE);
		lastlog_level = set_lastlog_msg_level(LOG_OPNOTE);
	}

	message_from(NULL, LOG_SNOTE);
	lastlog_level = set_lastlog_msg_level(LOG_SNOTE);
	
	if (*line != '*'  && *line != '#' && strncmp(line, "MOTD ", 4))
		flag = 1;
	else
		flag = 0;

  
	split_kill(line, &fr, &temp2,
			&server, &server2, &for_, &temp); 
	if (!server)
		server = "Local";
	if (!server2)
		server2 = "Local";
	if (!temp2)
		temp2 = "UNKNOWN";
	if (!temp)
		temp = "()";	

	if (strstr(line, "Notice -- Received KILL message for") && fr && for_)
	{
		if ((strcmp(server, "Local") == 0))
		{
			if (do_hook(SERVER_NOTICE_LOCAL_KILL_LIST, "%s %s %s %s", for_, server, fr, temp2, temp))
				say("Local Ircop Kill for %s by %s %s (%s %s)", for_, fr, temp2, server, temp);
		} else {
			if (do_hook(SERVER_NOTICE_FOREIGN_KILL_LIST, "%s %s %s %s", for_, server, fr, temp2, temp))
				say("Foreign Ircop Kill for %s by %s %s (%s %s)", for_, fr, temp2, server, temp);
		}
 	} 
 	else if (strstr(line, "Notice -- Nick change collision") && fr && for_)
	{
		if (!get_int_var(SHOW_SERVER_KILLS_VAR))
			goto done;  	
		if (do_hook(SERVER_NOTICE_SERVER_KILL_LIST,"%s %s %s %s", for_, fr, temp2, server, temp))
			put_it(flag ? "*** %s" : "%s", line);
	}
	else if (strstr(line, "Notice -- Nickname collision") && fr && for_)
	{
		if (!get_int_var(SHOW_SERVER_KILLS_VAR))
			goto done;  	
		if (do_hook(SERVER_NOTICE_SERVER_KILL_LIST, "%s %s %s %s", for_, fr, temp2, server, temp))
			put_it(flag ? "*** %s" : "%s", line);
	}
  	else if (strstr(line, "Notice -- Fake") && fr && for_)
  	{
		if (!get_int_var(SHOW_FAKES_VAR))
			goto done;  	
		/* SERVER_NOTICE_FAKES_MYCHANNEL_LIST */
		if (lookup_channel(fr, from_server, CHAN_NOUNLINK))
		{
			if (do_hook(SERVER_NOTICE_FAKES_MYCHANNEL_LIST, "%s %s %s %s", for_, fr, temp2, server, temp))
  				put_it(flag ? "*** %s" : "%s", line);
		}
		else 
		{
			if (do_hook(SERVER_NOTICE_FAKES_LIST, "%s %s %s %s", for_, fr, temp2, server, temp))
  				put_it(flag ? "*** %s" : "%s", line);
		}
  	}
  	else if (strstr(line, "Notice -- Unauth"))
  	{
		if (!get_int_var(SHOW_UNAUTHS_VAR))
			goto done;  	
		if (do_hook(SERVER_NOTICE_LIST, flag ? "%s *** %s" : "%s %s", from, line))
	               	put_it(flag ? "*** %s" : "%s", line);
	}
	else
	{
		if (!get_int_var(SHOW_SERVER_CRAP_VAR))
			goto done;  	
		if (do_hook(SERVER_NOTICE_LIST, flag ? "%s *** %s" : "%s %s", from, line))
	               	put_it(flag ? "*** %s" : "%s", line);
	}
done:	
	if (lastlog_level)
	{
		set_lastlog_msg_level(lastlog_level);
		message_from(NULL, lastlog_level);
	}
}

void 
parse_notice(from, Args)
	char 	*from;
	char 	**Args;
{
	int	level,
		type;
	char	*to;
	int	no_flooding;
	int	flag;
	char	*high,
		not_from_server = 1;
	char	*line;
	char    msg[BIG_BUFFER_SIZE +1];
	
	PasteArgs(Args, 1);
	to = Args[0];
	line = Args[1];
	if (!to || !line)
		return;
	if (*to)
	{
		if (is_channel(to))
		{
			message_from(to, LOG_NOTICE);
			type = PUBLIC_NOTICE_LIST;
		}
		else
		{
			message_from(from, LOG_NOTICE);
			type = NOTICE_LIST;
		}
		update_stats(type, to, from);		
		if (from && *from && strcmp(get_server_itsname(from_server), from))
		{
			switch ((flag = check_ignore(from, FromUserHost, IGNORE_NOTICES)))
			{
				case IGNORED:
					return;
				case HIGHLIGHTED:
					high = highlight_char;
					break;
				default:
					high = empty_string;
			}
		/*
		 * only dots in servernames, right ?
		 *
		 * But a server name doesn't nessicarily have to have
		 * a 'dot' in it..  - phone, jan 1993.
		 */
			if (index(from, '.'))
				not_from_server = 0;
			
			line = do_notice_ctcp(from, to, line);
			if (*line == (char) 0)
				return;
			level = set_lastlog_msg_level(LOG_NOTICE);
			no_flooding = check_flooding(from, NOTICE_FLOOD, line);
			
			if (sed == 1 && !do_hook(ENCRYPTED_NOTICE_LIST, "%s %s %s", from, to, line))
				sed = 0;
			else
			{
				if (type == NOTICE_LIST && no_flooding)
				{
					logmsg(0, "-", from, line, FromUserHost, 0);
					if (do_hook(type, "%s %s", from, line))
						put_it("%s-%s-%s %s", high, from, high, line);
				}
				else
				{
					new_free(&last_notice);
					last_notice = m_sprintf("%s-%s:%s-%s %s", high, from, high, to, line);
					if (do_hook(type, "%s %s %s", from, to, line))
						put_it("%s-%s:%s-%s %s", high, from, to, high, line);
                		        if (get_int_var(ANNOY_KICK_VAR))
						annoy_kicks(type, to, from, line);
					if (beep_on_level & LOG_NOTICE)
						beep_em(1);
				}
				new_free(&last_notice);
				sprintf(msg, "\002-%s:%s-\002 %s", from, to, line);
				malloc_strcpy(&last_notice, msg);
				set_lastlog_msg_level(level);
				if (not_from_server)
					notify_mark(from, 1, 0);
			}
		}
		else 
			parse_server_notice(from, line);
	}
	else
		put_it("%s", line + 1);
}

void load_scripts(void)
{
	char buffer[BIG_BUFFER_SIZE+1];
	if (never_connected)
	{
		
		strcpy(buffer, "global");
		never_connected = 0;

		loading_global = 1;
		load("LOAD", buffer, empty_string);
		loading_global = 0;

		/* read the .ircrc file */
		if (access(ircrc_file, R_OK) == 0 && !quick_startup)
			load("LOAD", ircrc_file, empty_string);
		else if (get_int_var(NOVICE_VAR))
			say("If you have not already done so, please read the new user information with /HELP NEWUSER");
		if (!quick_startup)
			reload_save(NULL, NULL, NULL);

	}
	else if (server_list[from_server].away)
		send_to_server("AWAY :%s", server_list[from_server].away);
}

#ifdef COMPAT_27
/* got_initial_version: this is called when ircii get the NOTICE in
 * all version of ircd before 2.8, or the 002 numeric for 2.8 and
 * beyond.  I guess its handled rather badly at the moment....
 * added by phone, late 1992.
 */
void
got_initial_version(line)
	char	*line;
{
	char	server[81],
		sversion[21];
	char	*c;
	
	if ((sscanf(line, "*** Your host is %80s running version %20s",
			server, sversion)) != 2)
		return;
			
	server[strlen(server) - 1] = '\0';
	attempting_to_connect--;
	set_server_motd(from_server, 1);
	server_is_connected(from_server, 1);
	if ((c = (char *) index(server, '[')) != NULL)
		*c = '\0';	/*
				 * Handles the case where the server name is
				 * different to the host name.
				 */
	set_server_version(from_server, Server2_7);

	malloc_strcpy(&server_list[from_server].version_string, sversion);
	set_server_itsname(from_server, server);
	reconnect_all_channels(from_server);
	reinstate_user_modes(); 
	update_all_status();
	do_hook(CONNECT_LIST, "%s %d", get_server_name(from_server),
		get_server_port(from_server));
}
#endif

/*
 * got_initial_version_28: this is called when ircii gets the serial
 * number 004 reply.  We do this becuase the 004 numeric gives us the
 * server name and version in a very easy to use fashion, and doesnt
 * rely on the syntax or construction of the 002 numeric.
 *
 * Hacked as neccesary by jfn, May 1995
 */
#ifdef __STDC__
extern void got_initial_version_28 (char **ArgList)
#else
extern void	got_initial_version_28(ArgList)
char	**ArgList;
#endif
{
	char *server, *sversion;

	server = ArgList[0];
	sversion = ArgList[1];
	
	attempting_to_connect--;
	set_server_motd(from_server, 1);
	server_is_connected(from_server, 1);
/*
	add_userhost_to_whois(get_server_nickname(from_server), got_my_userhost);
*/

	if (!strncmp(version, "2.8", 3))
	{
		if (strstr(version, "mu") || strstr(version, "me"))
			set_server_version(from_server, Server_u2_8);
		else
			set_server_version(from_server, Server2_8);
	}
	else if (!strncmp(version, "u2.9", 4))
		set_server_version(from_server, Server_u2_9);
	else if (!strncmp(version, "u2.10", 4))
		set_server_version(from_server, Server_u2_10);
	else if (!strncmp(version, "u3.0", 4))
		set_server_version(from_server, Server_u3_0);
	else
		set_server_version(from_server, Server2_8);

	malloc_strcpy(&server_list[from_server].version_string, sversion);
	set_server_itsname(from_server, server);
	reconnect_all_channels(from_server);
	reinstate_user_modes();

	update_all_status();
	do_hook(CONNECT_LIST, "%s %d", get_server_name(from_server),
		get_server_port(from_server));
}
